// PIC16F1827 Configuration Bit Settings

// 'C' source line config statements

#include <xc.h>

// #pragma config statements should precede project file includes.
// Use project enums instead of #define for ON and OFF.

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config CPD = OFF        // Data Memory Code Protection (Data memory code protection is disabled)
#pragma config BOREN = ON       // Brown-out Reset Enable (Brown-out Reset enabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)
#pragma config IESO = OFF       // Internal/External Switchover (Internal/External Switchover mode is disabled)
#pragma config FCMEN = OFF      // Fail-Safe Clock Monitor Enable (Fail-Safe Clock Monitor is disabled)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config PLLEN = OFF      // PLL Enable (4x PLL disabled)
#pragma config STVREN = ON      // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)

#define _XTAL_FREQ  8000000   // delay用(クロック8MHzで動作時)

// 指定した時間(num x 10ms)だけウエイトを行う処理関数
void Wait(unsigned int num){
    int i ;
    // numで指定した回数だけ繰り返す
    for (i=0 ; i<num ; i++) {
        __delay_ms(10) ;     // 10msプログラムの一時停止
    }
}
// メインの処理関数
void main(){

    OSCCON = 0b01110010;//内部クロック8MHz
    ANSELA = 0b00000000;//全てデジタルI/O
    ANSELB = 0b00000000;//全てデジタルI/O
    TRISA  = 0b00000000;//全て出力(RA5は入力のみ)
    TRISB  = 0b00000000;//全て出力

    //１秒毎にLEDを点滅

    while(1){
        RA0 = 1;//LED ON
        Wait(100);//１秒待つ
        RA0 = 0;//LED OFF
        Wait(100);
    }
}